DndDragEndEvent class final
Event emitted when the active drag ends.
- Inheritance
-
- Object
- DndDragEvent
- DndDragEndEvent
Constructors
- DndDragEndEvent({required DndDragSession session, DndId? overId})
-
Creates a drag end event.
const
Properties
- activeId → DndId
-
The stable id of the active draggable.
no setterinherited
- currentPointer → DndPoint
-
The latest pointer position known by this event.
no setterinherited
- delta → DndPoint
-
The movement from initialPointer to currentPointer.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setteroverride
- initialPointer → DndPoint
-
The pointer position when the session started.
no setterinherited
- inputKind → DndInputKind
-
The input source that activated this drag.
no setterinherited
- overId → DndId?
-
The droppable the active drag ended over, when one exists.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- session → DndDragSession
-
The drag session represented by this event.
finalinherited
- transform → DndTransform
-
A transform representing the current drag movement.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override